==> codeforlife-portal-4.15.0.tar.gz: codeforlife-portal-4.15.0/portal/views/aimmo/dashboard.py <==
from typing import Any, Dict, List, Optional

from aimmo.forms import AddGameForm
from aimmo.game_creator import create_game
from aimmo.models import Game, Worksheet
from common.permissions import logged_in_as_student, logged_in_as_teacher
from common.utils import LoginRequiredNoErrorMixin
from django.contrib import messages
from django.contrib.auth.mixins import UserPassesTestMixin
from django.core.exceptions import ObjectDoesNotExist
from django.db.models import QuerySet
from django.urls import reverse_lazy
from django.views.generic.base import TemplateView
from django.views.generic.edit import CreateView

from portal.strings.student_aimmo_dashboard import AIMMO_DASHBOARD_BANNER


class TeacherAimmoDashboard(LoginRequiredNoErrorMixin, UserPassesTestMixin, CreateView):
    login_url = reverse_lazy("teacher_login")
    form_class = AddGameForm
    template_name = "portal/teach/teacher_aimmo_dashboard.html"

    def test_func(self) -> Optional[bool]:
        return logged_in_as_teacher(self.request.user)

    def get_form(self, form_class=None):
        user = self.request.user
        classes = user.userprofile.teacher.class_teacher.all()
        if form_class is None:
            form_class = self.get_form_class()
        return form_class(classes, **self.get_form_kwargs())

    def form_valid(self, form):
        create_game(self.request.user, form)
        return super().form_valid(form)

    def form_invalid(self, form: AddGameForm):
        messages.warning(self.request, ", ".join(form.errors.get("__all__", [])))
        return super().form_invalid(form)

    def get_success_url(self):
        return reverse_lazy("kurono/play", args=(self.object.id,))


class StudentAimmoDashboard(
    LoginRequiredNoErrorMixin, UserPassesTestMixin, TemplateView
):
    template_name = "portal/play/student_aimmo_dashboard.html"

    login_url = reverse_lazy("student_login")

    def test_func(self) -> Optional[bool]:
        return logged_in_as_student(self.request.user)

    def get_context_data(self, **kwargs: Any) -> Dict[str, Any]:
        student = self.request.user.new_student
        klass = student.class_field

        if klass is None:
            return {"BANNER": AIMMO_DASHBOARD_BANNER}

        try:
            aimmo_game = Game.objects.get(game_class=klass)

            active_worksheet = aimmo_game.worksheet
            inactive_worksheets = Worksheet.objects.exclude(id=active_worksheet.id)

            return {
                "BANNER": AIMMO_DASHBOARD_BANNER,
                "HERO_CARD": self._get_hero_card(active_worksheet, aimmo_game),
                "CARD_LIST": {"cards": self._get_card_list(inactive_worksheets)},
            }

        except ObjectDoesNotExist:
            return {"BANNER": AIMMO_DASHBOARD_BANNER}

    def _get_hero_card(
        self, active_worksheet: Worksheet, aimmo_game: Game
    ) -> Dict[str, Any]:
        return {
            "image": active_worksheet.active_image_path,
            "title": active_worksheet.name,
            "description": active_worksheet.description,
            "button1": {
                "text": "Read challenge",
                "url": "materials_viewer",
                "url_args": active_worksheet.student_pdf_name,
            },
            "button2": {
                "text": "Start challenge",
                "url": "kurono/play",
                "url_args": aimmo_game.id,
            },
        }

    def _get_card_list(self, inactive_worksheets: QuerySet) -> List[Dict[str, Any]]:
        card_list = []

        for inactive_worksheet in inactive_worksheets:
            worksheet_info = {
                "image": inactive_worksheet.image_path,
                "title": inactive_worksheet.name,
                "description": inactive_worksheet.short_description,
                "thumbnail_text": inactive_worksheet.thumbnail_text,
                "thumbnail_image": inactive_worksheet.thumbnail_image_path,
            }
            card_list.append(worksheet_info)

        kurono_feedback_card = {
            "image": "images/worksheets/kurono_logo.png",
            "title": "Let us know what you think",
            "button_text": "Give feedback",
            "button_link": "https://docs.google.com/forms/d/e/1FAIpQLSeI8Fu-tdtIseAaCrDbtOqtAK4x_-SWKttJYrbFx-j52fBYMA/viewform?usp=sf_link",
        }
        card_list.append(kurono_feedback_card)

        return card_list

==> codeforlife-portal-6.29.1.tar.gz: codeforlife-portal-6.29.1/portal/views/aimmo/dashboard.py <==
from typing import Any, Dict, List, Optional

from aimmo.game_creator import create_game
from aimmo.models import Game
from common.models import Class
from aimmo.worksheets import WORKSHEETS, Worksheet, get_worksheets_excluding_id
from common.permissions import logged_in_as_student, logged_in_as_teacher
from common.utils import LoginRequiredNoErrorMixin
from django.contrib import messages
from django.contrib.auth.mixins import UserPassesTestMixin
from django.core.exceptions import ObjectDoesNotExist
from django.db.models import QuerySet
from django.urls import reverse_lazy
from django.views.generic.base import TemplateView
from django.views.generic.edit import CreateView

from portal.forms.add_game import AddGameForm
from portal.strings.student_aimmo_dashboard import AIMMO_DASHBOARD_BANNER


class TeacherAimmoDashboard(LoginRequiredNoErrorMixin, UserPassesTestMixin, CreateView):
    login_url = reverse_lazy("teacher_login")
    form_class = AddGameForm
    template_name = "portal/teach/teacher_aimmo_dashboard.html"

    def test_func(self) -> Optional[bool]:
        return logged_in_as_teacher(self.request.user)

    def get_form(self, form_class=None):
        teacher = self.request.user.new_teacher
        non_admin_classes = teacher.class_teacher
        admin_classes = Class.objects.filter(teacher__school=teacher.school)
        classes = admin_classes if teacher.is_admin else non_admin_classes
        if form_class is None:
            form_class = self.get_form_class()
        return form_class(classes, **self.get_form_kwargs())

    def form_valid(self, form):
        create_game(self.request.user, form)
        return super().form_valid(form)

    def form_invalid(self, form: AddGameForm):
        messages.warning(
            self.request,
            ", ".join(message for errors in form.errors.values() for message in errors),
        )
        return super().form_invalid(form)

    def get_success_url(self):
        return reverse_lazy("teacher_aimmo_dashboard")


class StudentAimmoDashboard(LoginRequiredNoErrorMixin, UserPassesTestMixin, TemplateView):
    template_name = "portal/play/student_aimmo_dashboard.html"

    login_url = reverse_lazy("student_login_access_code")

    def test_func(self) -> Optional[bool]:
        return logged_in_as_student(self.request.user)

    def get_context_data(self, **kwargs: Any) -> Dict[str, Any]:
        student = self.request.user.new_student
        klass = student.class_field

        if klass is None:
            return {"BANNER": AIMMO_DASHBOARD_BANNER}

        aimmo_game = klass.active_game
        if aimmo_game:
            active_worksheet = WORKSHEETS.get(aimmo_game.worksheet_id)
            inactive_worksheets = get_worksheets_excluding_id(active_worksheet.id)

            return {
                "BANNER": AIMMO_DASHBOARD_BANNER,
                "HERO_CARD": self._get_hero_card(active_worksheet, aimmo_game),
                "CARD_LIST": {"cards": self._get_card_list(inactive_worksheets)},
            }
        else:
            return {"BANNER": AIMMO_DASHBOARD_BANNER}

    def _get_hero_card(self, active_worksheet: Worksheet, aimmo_game: Game) -> Dict[str, Any]:
        return {
            "image": active_worksheet.active_image_path,
            "title": active_worksheet.name,
            "description": active_worksheet.description,
            "button1": {
                "text": "Read challenge",
                "url": active_worksheet.student_challenge_url,
            },
            "button2": {
                "text": "Play game",
                "url": "kurono/play",
                "url_args": aimmo_game.id,
            },
        }

    def _get_card_list(self, inactive_worksheets: QuerySet) -> List[Dict[str, Any]]:
        return [
            {
                "image": inactive_worksheet.image_path,
                "title": inactive_worksheet.name,
                "description": inactive_worksheet.short_description,
            }
            for inactive_worksheet in inactive_worksheets
        ]
